pub struct Constant<S: Shaped + IntoSpec>(pub S);Expand description
Source node for numerical constants.
This node implements both Function and Differentiable. The former simply returns the wrapped value, and the latter returns an instance of ConstantAdjoint that handles (empty) buffer shaping.
Examples
let cns = Constant([10.0, 10.0]);
let jac = cns.adjoint(X);
assert_eq!(cns.evaluate(ctx!{X = [1.0, 2.0]}).unwrap(), [10.0, 10.0]);
assert_eq!(jac.evaluate(ctx!{X = [1.0, 2.0]}).unwrap(), [
[0.0, 0.0],
[0.0, 0.0]
]);Tuple Fields
0: STrait Implementations
Sourceimpl<T, B> Differentiable<T> for Constant<B>
impl<T, B> Differentiable<T> for Constant<B>
Sourcetype Adjoint = ConstantAdjoint<Constant<B>, T>
type Adjoint = ConstantAdjoint<Constant<B>, T>
The adjoint operator; i.e. the gradient.
Sourcefn evaluate_adjoint<C: Context, CR: AsRef<C>>(
&self,
target: T,
ctx: CR,
) -> AegirResult<Self::Adjoint, C>
fn evaluate_adjoint<C: Context, CR: AsRef<C>>( &self, target: T, ctx: CR, ) -> AegirResult<Self::Adjoint, C>
Helper method that computes the adjoint and evaluates its value. Read more
Sourceimpl<C, S> Function<C> for Constant<S>
impl<C, S> Function<C> for Constant<S>
Sourceimpl<S: Shaped + IntoSpec> Node for Constant<S>
impl<S: Shaped + IntoSpec> Node for Constant<S>
fn add<N: Node>(self, other: N) -> Add<Self, N>where
Self: Sized,
fn sub<N: Node>(self, other: N) -> Sub<Self, N>where
Self: Sized,
fn mul<N: Node>(self, other: N) -> Mul<Self, N>where
Self: Sized,
fn div<N: Node>(self, other: N) -> Div<Self, N>where
Self: Sized,
fn dot<N: Node>(self, other: N) -> TensorDot<Self, N>where
Self: Sized,
fn abs(self) -> Abs<Self>where
Self: Sized,
fn neg(self) -> Negate<Self>where
Self: Sized,
fn pow<P>(self, power: P) -> Power<Self, P>where
Self: Sized,
fn ln(self) -> Ln<Self>where
Self: Sized,
fn squared(self) -> Square<Self>where
Self: Sized,
fn sum(self) -> Sum<Self>where
Self: Sized,
fn sigmoid(self) -> Sigmoid<Self>where
Self: Sized,
impl<S: Copy + Shaped + IntoSpec> Copy for Constant<S>
impl<S: Eq + Shaped + IntoSpec> Eq for Constant<S>
impl<S: Shaped + IntoSpec> StructuralPartialEq for Constant<S>